list(rd_family_title = list(
  common = "Other commonly-used functions: ",
  reading = "Other functions for reading in CIFTI or GIFTI data: ",
  writing = "Other functions for writing CIFTI or GIFTI data: ",
  surfing = "Other functions for working with GIFTI surface geometry data: ",
  manipulating = "Other functions for manipulating `xifti` objects: "
))